@@ -16,17 +16,24 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
+"""
+Stacked Line chart
+
+"""
+
 from pygal.graph.line import Line
-from pygal.interpolate import interpolation
-from math import isnan
 from itertools import izip_longest
 
 
 class StackedLine(Line):
     """Stacked Line graph"""
 
+    def __init__(self, *args, **kwargs):
+        self._previous_line = None
+        super(StackedLine, self).__init__(*args, **kwargs)
+
     def _fill(self, values):
-        if not hasattr(self, '_previous_line'):
+        if not self._previous_line:
             self._previous_line = values
             return super(StackedLine, self)._fill(values)
         new_values = values + list(reversed(self._previous_line))
@@ -34,7 +41,8 @@ class StackedLine(Line):
         return new_values
 
     def _compute(self):
-        self._x_pos = [x / float(self._len - 1) for x in range(self._len)
+        self._uniformize_data()
+        x_pos = [x / float(self._len - 1) for x in range(self._len)
         ] if self._len != 1 else [.5]  # Center if only one value
         accumulation = [0] * self._len
         for serie in self.series:
@@ -43,14 +51,8 @@ class StackedLine(Line):
                                if val != None else 0
                                for val in serie.values], fillvalue=0))
             serie.points = [
-                (self._x_pos[i], v)
+                (x_pos[i], v)
                 for i, v in enumerate(accumulation)]
             if self.interpolate:
-                interpolate = interpolation(
-                    self._x_pos, accumulation, kind=self.interpolate)
-                p = float(self.interpolation_precision)
-                serie.interpolated = [
-                    (x / p, float(interpolate(x / p)))
-                    for x in range(int(p + 1))
-                    if not isnan(float(interpolate(x / p)))]
+                serie.interpolated = self._interpolate(accumulation, x_pos)
         return super(StackedLine, self)._compute()
